@@ -2,6 +2,8 @@
 // for details. All rights reserved. Use of this source code is governed by a
 // BSD-style license that can be found in the LICENSE file.
 
+// ignore_for_file: analyzer_use_new_elements
+
 import 'package:analyzer/dart/analysis/features.dart';
 import 'package:analyzer/dart/element/element.dart';
 import 'package:analyzer/dart/element/nullability_suffix.dart';
@@ -13,6 +15,8 @@ import 'package:analyzer/src/dart/element/type.dart';
 import 'package:analyzer/src/generated/engine.dart' as engine;
 import 'package:analyzer/src/generated/testing/element_factory.dart';
 import 'package:analyzer/src/generated/utilities_dart.dart';
+import 'package:analyzer/src/summary2/reference.dart';
+import 'package:analyzer/src/utilities/extensions/string.dart';
 
 class MockSdkElements {
   final LibraryElementImpl coreLibrary;
@@ -25,6 +29,8 @@ class MockSdkElements {
     var builder = _MockSdkElementsBuilder(analysisContext, analysisSession);
     var coreLibrary = builder._buildCore();
     var asyncLibrary = builder._buildAsync();
+    builder._populateCore();
+    builder._populateAsync();
     return MockSdkElements._(coreLibrary, asyncLibrary);
   }
 
@@ -61,13 +67,19 @@ class _MockSdkElementsBuilder {
   ClassElementImpl? _symbolElement;
   ClassElementImpl? _typeElement;
 
-  InterfaceType? _boolType;
-  InterfaceType? _doubleType;
-  InterfaceType? _intType;
-  InterfaceType? _numType;
-  InterfaceType? _objectType;
-  InterfaceType? _stringType;
-  InterfaceType? _typeType;
+  InterfaceTypeImpl? _boolType;
+  InterfaceTypeImpl? _doubleType;
+  InterfaceTypeImpl? _intType;
+  InterfaceTypeImpl? _numType;
+  InterfaceTypeImpl? _objectType;
+  InterfaceTypeImpl? _stringType;
+  InterfaceTypeImpl? _typeType;
+
+  late LibraryElementImpl _asyncLibrary;
+  late CompilationUnitElementImpl _asyncUnit;
+
+  late LibraryElementImpl _coreLibrary;
+  late CompilationUnitElementImpl _coreUnit;
 
   _MockSdkElementsBuilder(
     this.analysisContext,
@@ -78,7 +90,7 @@ class _MockSdkElementsBuilder {
     var boolElement = _boolElement;
     if (boolElement != null) return boolElement;
 
-    _boolElement = boolElement = _class(name: 'bool');
+    _boolElement = boolElement = _class(name: 'bool', unit: _coreUnit);
     boolElement.supertype = objectType;
 
     boolElement.constructors = [
@@ -93,10 +105,11 @@ class _MockSdkElementsBuilder {
       ),
     ];
 
+    _buildClassElement(boolElement);
     return boolElement;
   }
 
-  InterfaceType get boolType {
+  InterfaceTypeImpl get boolType {
     return _boolType ??= _interfaceType(boolElement);
   }
 
@@ -109,9 +122,11 @@ class _MockSdkElementsBuilder {
       name: 'Comparable',
       isAbstract: true,
       typeParameters: [tElement],
+      unit: _coreUnit,
     );
     comparableElement.supertype = objectType;
 
+    _buildClassElement(comparableElement);
     return comparableElement;
   }
 
@@ -124,9 +139,11 @@ class _MockSdkElementsBuilder {
       name: 'Completer',
       isAbstract: true,
       typeParameters: [tElement],
+      unit: _asyncUnit,
     );
     completerElement.supertype = objectType;
 
+    _buildClassElement(completerElement);
     return completerElement;
   }
 
@@ -134,7 +151,8 @@ class _MockSdkElementsBuilder {
     var deprecatedElement = _deprecatedElement;
     if (deprecatedElement != null) return deprecatedElement;
 
-    _deprecatedElement = deprecatedElement = _class(name: 'Deprecated');
+    _deprecatedElement =
+        deprecatedElement = _class(name: 'Deprecated', unit: _coreUnit);
     deprecatedElement.supertype = objectType;
 
     deprecatedElement.fields = [
@@ -153,6 +171,7 @@ class _MockSdkElementsBuilder {
       ),
     ];
 
+    _buildClassElement(deprecatedElement);
     return deprecatedElement;
   }
 
@@ -163,6 +182,7 @@ class _MockSdkElementsBuilder {
     _doubleElement = doubleElement = _class(
       name: 'double',
       isAbstract: true,
+      unit: _coreUnit,
     );
     doubleElement.supertype = numType;
 
@@ -214,10 +234,11 @@ class _MockSdkElementsBuilder {
       _method('truncate', doubleType),
     ];
 
+    _buildClassElement(doubleElement);
     return doubleElement;
   }
 
-  InterfaceType get doubleType {
+  InterfaceTypeImpl get doubleType {
     return _doubleType ??= _interfaceType(doubleElement);
   }
 
@@ -230,13 +251,15 @@ class _MockSdkElementsBuilder {
     _functionElement = functionElement = _class(
       name: 'Function',
       isAbstract: true,
+      unit: _coreUnit,
     );
     functionElement.supertype = objectType;
 
+    _buildClassElement(functionElement);
     return functionElement;
   }
 
-  InterfaceType get functionType {
+  InterfaceTypeImpl get functionType {
     return _interfaceType(functionElement);
   }
 
@@ -251,6 +274,7 @@ class _MockSdkElementsBuilder {
       name: 'Future',
       isAbstract: true,
       typeParameters: [tElement],
+      unit: _asyncUnit,
     );
     futureElement.supertype = objectType;
 
@@ -286,6 +310,7 @@ class _MockSdkElementsBuilder {
       ),
     ];
 
+    _buildClassElement(futureElement);
     return futureElement;
   }
 
@@ -297,9 +322,11 @@ class _MockSdkElementsBuilder {
     _futureOrElement = futureOrElement = _class(
       name: 'FutureOr',
       typeParameters: [tElement],
+      unit: _asyncUnit,
     );
     futureOrElement.supertype = objectType;
 
+    _buildClassElement(futureOrElement);
     return futureOrElement;
   }
 
@@ -307,7 +334,8 @@ class _MockSdkElementsBuilder {
     var intElement = _intElement;
     if (intElement != null) return intElement;
 
-    _intElement = intElement = _class(name: 'int', isAbstract: true);
+    _intElement =
+        intElement = _class(name: 'int', isAbstract: true, unit: _coreUnit);
     intElement.supertype = numType;
 
     intElement.constructors = [
@@ -348,10 +376,11 @@ class _MockSdkElementsBuilder {
       _method('toString', stringType),
     ];
 
+    _buildClassElement(intElement);
     return intElement;
   }
 
-  InterfaceType get intType {
+  InterfaceTypeImpl get intType {
     return _intType ??= _interfaceType(intElement);
   }
 
@@ -366,6 +395,7 @@ class _MockSdkElementsBuilder {
       name: 'Iterable',
       isAbstract: true,
       typeParameters: [eElement],
+      unit: _coreUnit,
     );
     iterableElement.supertype = objectType;
 
@@ -378,6 +408,7 @@ class _MockSdkElementsBuilder {
       _getter('last', eType),
     ]);
 
+    _buildClassElement(iterableElement);
     return iterableElement;
   }
 
@@ -392,6 +423,7 @@ class _MockSdkElementsBuilder {
       name: 'Iterator',
       isAbstract: true,
       typeParameters: [eElement],
+      unit: _coreUnit,
     );
     iteratorElement.supertype = objectType;
 
@@ -399,6 +431,7 @@ class _MockSdkElementsBuilder {
       _getter('current', eType),
     ]);
 
+    _buildClassElement(iteratorElement);
     return iteratorElement;
   }
 
@@ -413,6 +446,7 @@ class _MockSdkElementsBuilder {
       name: 'List',
       isAbstract: true,
       typeParameters: [eElement],
+      unit: _coreUnit,
     );
     listElement.supertype = objectType;
     listElement.interfaces = [
@@ -442,6 +476,7 @@ class _MockSdkElementsBuilder {
       ]),
     ];
 
+    _buildClassElement(listElement);
     return listElement;
   }
 
@@ -458,6 +493,7 @@ class _MockSdkElementsBuilder {
       name: 'Map',
       isAbstract: true,
       typeParameters: [kElement, vElement],
+      unit: _coreUnit,
     );
     mapElement.supertype = objectType;
 
@@ -475,6 +511,7 @@ class _MockSdkElementsBuilder {
       ]),
     ];
 
+    _buildClassElement(mapElement);
     return mapElement;
   }
 
@@ -482,7 +519,7 @@ class _MockSdkElementsBuilder {
     var nullElement = _nullElement;
     if (nullElement != null) return nullElement;
 
-    _nullElement = nullElement = _class(name: 'Null');
+    _nullElement = nullElement = _class(name: 'Null', unit: _coreUnit);
     nullElement.supertype = objectType;
 
     nullElement.constructors = [
@@ -492,6 +529,7 @@ class _MockSdkElementsBuilder {
       ),
     ];
 
+    _buildClassElement(nullElement);
     return nullElement;
   }
 
@@ -499,7 +537,8 @@ class _MockSdkElementsBuilder {
     var numElement = _numElement;
     if (numElement != null) return numElement;
 
-    _numElement = numElement = _class(name: 'num', isAbstract: true);
+    _numElement =
+        numElement = _class(name: 'num', isAbstract: true, unit: _coreUnit);
     numElement.supertype = objectType;
     numElement.interfaces = [
       _interfaceType(
@@ -572,10 +611,11 @@ class _MockSdkElementsBuilder {
       _getter('isNegative', boolType),
     ]);
 
+    _buildClassElement(numElement);
     return numElement;
   }
 
-  InterfaceType get numType {
+  InterfaceTypeImpl get numType {
     return _numType ??= _interfaceType(numElement);
   }
 
@@ -584,9 +624,10 @@ class _MockSdkElementsBuilder {
     if (objectElement != null) return objectElement;
 
     _objectElement = objectElement = ElementFactory.object;
+    _coreUnit.encloseElement(objectElement);
     objectElement.interfaces = const <InterfaceType>[];
     objectElement.mixins = const <InterfaceType>[];
-    objectElement.typeParameters = const <TypeParameterElement>[];
+    objectElement.typeParameters = const <TypeParameterElementImpl>[];
     objectElement.constructors = [
       _constructor(isConst: true),
     ];
@@ -606,10 +647,11 @@ class _MockSdkElementsBuilder {
       _getter('runtimeType', typeType),
     ]);
 
+    _buildClassElement(objectElement);
     return objectElement;
   }
 
-  InterfaceType get objectType {
+  InterfaceTypeImpl get objectType {
     return _objectType ??= _interfaceType(objectElement);
   }
 
@@ -617,13 +659,15 @@ class _MockSdkElementsBuilder {
     var overrideElement = _overrideElement;
     if (overrideElement != null) return overrideElement;
 
-    _overrideElement = overrideElement = _class(name: '_Override');
+    _overrideElement =
+        overrideElement = _class(name: '_Override', unit: _coreUnit);
     overrideElement.supertype = objectType;
 
     overrideElement.constructors = [
       _constructor(isConst: true),
     ];
 
+    _buildClassElement(overrideElement);
     return overrideElement;
   }
 
@@ -634,13 +678,15 @@ class _MockSdkElementsBuilder {
     _recordElement = recordElement = _class(
       name: 'Record',
       isAbstract: true,
+      unit: _coreUnit,
     );
     recordElement.supertype = objectType;
 
+    _buildClassElement(recordElement);
     return recordElement;
   }
 
-  InterfaceType get recordType {
+  InterfaceTypeImpl get recordType {
     return _interfaceType(recordElement);
   }
 
@@ -655,12 +701,14 @@ class _MockSdkElementsBuilder {
       name: 'Set',
       isAbstract: true,
       typeParameters: [eElement],
+      unit: _coreUnit,
     );
     setElement.supertype = objectType;
     setElement.interfaces = [
       iterableType(eType),
     ];
 
+    _buildClassElement(setElement);
     return setElement;
   }
 
@@ -671,9 +719,11 @@ class _MockSdkElementsBuilder {
     _stackTraceElement = stackTraceElement = _class(
       name: 'StackTrace',
       isAbstract: true,
+      unit: _coreUnit,
     );
     stackTraceElement.supertype = objectType;
 
+    _buildClassElement(stackTraceElement);
     return stackTraceElement;
   }
 
@@ -688,6 +738,7 @@ class _MockSdkElementsBuilder {
       name: 'Stream',
       isAbstract: true,
       typeParameters: [tElement],
+      unit: _asyncUnit,
     );
     streamElement.isAbstract = true;
     streamElement.supertype = objectType;
@@ -718,6 +769,7 @@ class _MockSdkElementsBuilder {
       ),
     ];
 
+    _buildClassElement(streamElement);
     return streamElement;
   }
 
@@ -730,9 +782,11 @@ class _MockSdkElementsBuilder {
       name: 'StreamSubscription',
       isAbstract: true,
       typeParameters: [tElement],
+      unit: _asyncUnit,
     );
     streamSubscriptionElement.supertype = objectType;
 
+    _buildClassElement(streamSubscriptionElement);
     return streamSubscriptionElement;
   }
 
@@ -743,6 +797,7 @@ class _MockSdkElementsBuilder {
     _stringElement = stringElement = _class(
       name: 'String',
       isAbstract: true,
+      unit: _coreUnit,
     );
     stringElement.supertype = objectType;
 
@@ -772,10 +827,11 @@ class _MockSdkElementsBuilder {
       _method('toUpperCase', stringType),
     ];
 
+    _buildClassElement(stringElement);
     return stringElement;
   }
 
-  InterfaceType get stringType {
+  InterfaceTypeImpl get stringType {
     return _stringType ??= _interfaceType(stringElement);
   }
 
@@ -786,6 +842,7 @@ class _MockSdkElementsBuilder {
     _symbolElement = symbolElement = _class(
       name: 'Symbol',
       isAbstract: true,
+      unit: _coreUnit,
     );
     symbolElement.supertype = objectType;
 
@@ -799,6 +856,7 @@ class _MockSdkElementsBuilder {
       ),
     ];
 
+    _buildClassElement(symbolElement);
     return symbolElement;
   }
 
@@ -809,54 +867,56 @@ class _MockSdkElementsBuilder {
     _typeElement = typeElement = _class(
       name: 'Type',
       isAbstract: true,
+      unit: _coreUnit,
     );
     typeElement.supertype = objectType;
 
+    _buildClassElement(typeElement);
     return typeElement;
   }
 
-  InterfaceType get typeType {
+  InterfaceTypeImpl get typeType {
     return _typeType ??= _interfaceType(typeElement);
   }
 
   VoidTypeImpl get voidType => VoidTypeImpl.instance;
 
-  InterfaceType futureOrType(DartType elementType) {
+  InterfaceTypeImpl futureOrType(DartType elementType) {
     return _interfaceType(
       futureOrElement,
       typeArguments: [elementType],
     );
   }
 
-  InterfaceType futureType(DartType elementType) {
+  InterfaceTypeImpl futureType(DartType elementType) {
     return _interfaceType(
       futureElement,
       typeArguments: [elementType],
     );
   }
 
-  InterfaceType iterableType(DartType elementType) {
+  InterfaceTypeImpl iterableType(DartType elementType) {
     return _interfaceType(
       iterableElement,
       typeArguments: [elementType],
     );
   }
 
-  InterfaceType iteratorType(DartType elementType) {
+  InterfaceTypeImpl iteratorType(DartType elementType) {
     return _interfaceType(
       iteratorElement,
       typeArguments: [elementType],
     );
   }
 
-  InterfaceType listType(DartType elementType) {
+  InterfaceTypeImpl listType(DartType elementType) {
     return _interfaceType(
       listElement,
       typeArguments: [elementType],
     );
   }
 
-  InterfaceType streamSubscriptionType(DartType valueType) {
+  InterfaceTypeImpl streamSubscriptionType(DartType valueType) {
     return _interfaceType(
       streamSubscriptionElement,
       typeArguments: [valueType],
@@ -865,21 +925,7 @@ class _MockSdkElementsBuilder {
 
   LibraryElementImpl _buildAsync() {
     var asyncSource = analysisContext.sourceFactory.forUri('dart:async')!;
-    var asyncUnit = CompilationUnitElementImpl(
-      source: asyncSource,
-      librarySource: asyncSource,
-      lineInfo: LineInfo([0]),
-    );
-
-    asyncUnit.classes = <ClassElementImpl>[
-      completerElement,
-      futureElement,
-      futureOrElement,
-      streamElement,
-      streamSubscriptionElement
-    ];
-
-    var asyncLibrary = LibraryElementImpl(
+    _asyncLibrary = LibraryElementImpl(
       analysisContext,
       analysisSession,
       'dart.async',
@@ -887,20 +933,187 @@ class _MockSdkElementsBuilder {
       0,
       FeatureSet.latestLanguageVersion(),
     );
-    asyncLibrary.definingCompilationUnit = asyncUnit;
 
-    return asyncLibrary;
+    _asyncUnit = CompilationUnitElementImpl(
+      library: _asyncLibrary,
+      source: asyncSource,
+      lineInfo: LineInfo([0]),
+    );
+
+    _asyncLibrary.definingCompilationUnit = _asyncUnit;
+    return _asyncLibrary;
+  }
+
+  void _buildClassElement(ClassElementImpl fragment) {
+    var element = fragment.element;
+    element.mixins = fragment.mixins;
+    element.interfaces = fragment.interfaces;
+    element.fields = fragment.fields;
+    element.constructors = fragment.constructors;
+    element.accessors = fragment.accessors;
+    element.methods = fragment.methods;
   }
 
   LibraryElementImpl _buildCore() {
     var coreSource = analysisContext.sourceFactory.forUri('dart:core')!;
-    var coreUnit = CompilationUnitElementImpl(
+    _coreLibrary = LibraryElementImpl(
+      analysisContext,
+      analysisSession,
+      'dart.core',
+      0,
+      0,
+      FeatureSet.latestLanguageVersion(),
+    );
+
+    _coreUnit = CompilationUnitElementImpl(
+      library: _coreLibrary,
       source: coreSource,
-      librarySource: coreSource,
       lineInfo: LineInfo([0]),
     );
 
-    coreUnit.classes = <ClassElementImpl>[
+    _coreLibrary.definingCompilationUnit = _coreUnit;
+    return _coreLibrary;
+  }
+
+  ClassElementImpl _class({
+    required String name,
+    bool isAbstract = false,
+    List<TypeParameterElementImpl> typeParameters = const [],
+    required CompilationUnitElementImpl unit,
+  }) {
+    var fragment = ClassElementImpl(name, 0);
+    ClassElementImpl2(Reference.root(), fragment);
+    fragment.typeParameters = typeParameters;
+    fragment.constructors = <ConstructorElementImpl>[
+      _constructor(),
+    ];
+    unit.encloseElement(fragment);
+    return fragment;
+  }
+
+  ConstructorElementImpl _constructor({
+    String name = '',
+    bool isConst = false,
+    bool isFactory = false,
+    List<ParameterElementImpl> parameters = const [],
+  }) {
+    var element = ConstructorElementImpl(name, 0);
+    element.name2 = name.ifNotEmptyOrElse('new');
+    element.isFactory = isFactory;
+    element.isConst = isConst;
+    element.parameters = parameters;
+    return element;
+  }
+
+  FieldElementImpl _field(
+    String name,
+    TypeImpl type, {
+    bool isConst = false,
+    bool isFinal = false,
+    bool isStatic = false,
+  }) {
+    return ElementFactory.fieldElement(name, isStatic, isFinal, isConst, type);
+  }
+
+  FunctionElementImpl _function(
+    String name,
+    DartType returnType, {
+    List<TypeParameterElementImpl> typeFormals = const [],
+    List<ParameterElementImpl> parameters = const [],
+  }) {
+    var fragment = FunctionElementImpl(name, 0)
+      ..parameters = parameters
+      ..returnType = returnType
+      ..typeParameters = typeFormals;
+    TopLevelFunctionElementImpl(Reference.root(), fragment);
+    return fragment;
+  }
+
+  FunctionTypeImpl _functionType({
+    required DartType returnType,
+    List<TypeParameterElement> typeFormals = const [],
+    List<ParameterElement> parameters = const [],
+  }) {
+    return FunctionTypeImpl(
+      typeFormals: typeFormals,
+      parameters: parameters,
+      returnType: returnType,
+      nullabilitySuffix: NullabilitySuffix.none,
+    );
+  }
+
+  PropertyAccessorElementImpl _getter(
+    String name,
+    TypeImpl type, {
+    bool isStatic = false,
+  }) {
+    var field = FieldElementImpl(name, -1);
+    field.isStatic = isStatic;
+    field.isSynthetic = true;
+    field.type = type;
+
+    var getter = PropertyAccessorElementImpl(name, 0);
+    getter.isGetter = true;
+    getter.isStatic = isStatic;
+    getter.isSynthetic = false;
+    getter.returnType = type;
+    getter.variable2 = field;
+
+    field.getter = getter;
+    return getter;
+  }
+
+  InterfaceTypeImpl _interfaceType(
+    InterfaceElementImpl element, {
+    List<DartType> typeArguments = const [],
+  }) {
+    return InterfaceTypeImpl(
+      element: element.element,
+      typeArguments: typeArguments,
+      nullabilitySuffix: NullabilitySuffix.none,
+    );
+  }
+
+  MethodElementImpl _method(
+    String name,
+    DartType returnType, {
+    List<TypeParameterElementImpl> typeFormals = const [],
+    List<ParameterElementImpl> parameters = const [],
+  }) {
+    var fragment = MethodElementImpl(name, 0)
+      ..parameters = parameters
+      ..returnType = returnType
+      ..typeParameters = typeFormals;
+    MethodElementImpl2(Reference.root(), name, fragment);
+    return fragment;
+  }
+
+  ParameterElementImpl _namedParameter(String name, TypeImpl type,
+      {String? initializerCode}) {
+    var parameter = DefaultParameterElementImpl(
+      name: name,
+      nameOffset: 0,
+      parameterKind: ParameterKind.NAMED,
+    );
+    parameter.type = type;
+    parameter.defaultValueCode = initializerCode;
+    return parameter;
+  }
+
+  void _populateAsync() {
+    _asyncUnit.classes = <ClassElementImpl>[
+      completerElement,
+      futureElement,
+      futureOrElement,
+      streamElement,
+      streamSubscriptionElement
+    ];
+
+    _fillLibraryFromFragment(_asyncLibrary, _asyncUnit);
+  }
+
+  void _populateCore() {
+    _coreUnit.classes = <ClassElementImpl>[
       boolElement,
       comparableElement,
       deprecatedElement,
@@ -923,7 +1136,7 @@ class _MockSdkElementsBuilder {
       typeElement,
     ];
 
-    coreUnit.functions = <FunctionElementImpl>[
+    _coreUnit.functions = <FunctionElementImpl>[
       _function('identical', boolType, parameters: [
         _requiredParameter('a', objectType),
         _requiredParameter('b', objectType),
@@ -943,146 +1156,20 @@ class _MockSdkElementsBuilder {
       _interfaceType(overrideElement),
     );
 
-    coreUnit.accessors = <PropertyAccessorElementImpl>[
+    _coreUnit.accessors = <PropertyAccessorElementImpl>[
       deprecatedVariable.getter!,
       overrideVariable.getter!,
     ];
-    coreUnit.topLevelVariables = <TopLevelVariableElementImpl>[
+
+    _coreUnit.topLevelVariables = <TopLevelVariableElementImpl>[
       deprecatedVariable,
       overrideVariable,
     ];
 
-    var coreLibrary = LibraryElementImpl(
-      analysisContext,
-      analysisSession,
-      'dart.core',
-      0,
-      0,
-      FeatureSet.latestLanguageVersion(),
-    );
-    coreLibrary.definingCompilationUnit = coreUnit;
-
-    return coreLibrary;
+    _fillLibraryFromFragment(_coreLibrary, _coreUnit);
   }
 
-  ClassElementImpl _class({
-    required String name,
-    bool isAbstract = false,
-    List<TypeParameterElement> typeParameters = const [],
-  }) {
-    var element = ClassElementImpl(name, 0);
-    element.typeParameters = typeParameters;
-    element.constructors = <ConstructorElementImpl>[
-      _constructor(),
-    ];
-    return element;
-  }
-
-  ConstructorElementImpl _constructor({
-    String name = '',
-    bool isConst = false,
-    bool isFactory = false,
-    List<ParameterElement> parameters = const [],
-  }) {
-    var element = ConstructorElementImpl(name, 0);
-    element.isFactory = isFactory;
-    element.isConst = isConst;
-    element.parameters = parameters;
-    return element;
-  }
-
-  FieldElementImpl _field(
-    String name,
-    DartType type, {
-    bool isConst = false,
-    bool isFinal = false,
-    bool isStatic = false,
-  }) {
-    return ElementFactory.fieldElement(name, isStatic, isFinal, isConst, type);
-  }
-
-  FunctionElementImpl _function(
-    String name,
-    DartType returnType, {
-    List<TypeParameterElement> typeFormals = const [],
-    List<ParameterElement> parameters = const [],
-  }) {
-    return FunctionElementImpl(name, 0)
-      ..parameters = parameters
-      ..returnType = returnType
-      ..typeParameters = typeFormals;
-  }
-
-  FunctionType _functionType({
-    required DartType returnType,
-    List<TypeParameterElement> typeFormals = const [],
-    List<ParameterElement> parameters = const [],
-  }) {
-    return FunctionTypeImpl(
-      typeFormals: typeFormals,
-      parameters: parameters,
-      returnType: returnType,
-      nullabilitySuffix: NullabilitySuffix.none,
-    );
-  }
-
-  PropertyAccessorElementImpl _getter(
-    String name,
-    DartType type, {
-    bool isStatic = false,
-  }) {
-    var field = FieldElementImpl(name, -1);
-    field.isStatic = isStatic;
-    field.isSynthetic = true;
-    field.type = type;
-
-    var getter = PropertyAccessorElementImpl(name, 0);
-    getter.isGetter = true;
-    getter.isStatic = isStatic;
-    getter.isSynthetic = false;
-    getter.returnType = type;
-    getter.variable = field;
-
-    field.getter = getter;
-    return getter;
-  }
-
-  InterfaceType _interfaceType(
-    InterfaceElement element, {
-    List<DartType> typeArguments = const [],
-  }) {
-    return InterfaceTypeImpl(
-      element: element,
-      typeArguments: typeArguments,
-      nullabilitySuffix: NullabilitySuffix.none,
-    );
-  }
-
-  MethodElementImpl _method(
-    String name,
-    DartType returnType, {
-    List<TypeParameterElement> typeFormals = const [],
-    List<ParameterElement> parameters = const [],
-  }) {
-    return MethodElementImpl(name, 0)
-      ..parameters = parameters
-      ..returnType = returnType
-      ..typeParameters = typeFormals;
-  }
-
-  ParameterElement _namedParameter(String name, DartType type,
-      {String? initializerCode}) {
-    var parameter = DefaultParameterElementImpl(
-      name: name,
-      nameOffset: 0,
-      parameterKind: ParameterKind.NAMED,
-    );
-    parameter.type = type;
-    parameter.defaultValueCode = initializerCode;
-    return parameter;
-  }
-
-  ParameterElement _positionalParameter(String name, DartType type) {
+  ParameterElementImpl _positionalParameter(String name, TypeImpl type) {
     var parameter = ParameterElementImpl(
       name: name,
       nameOffset: 0,
@@ -1092,7 +1179,7 @@ class _MockSdkElementsBuilder {
     return parameter;
   }
 
-  ParameterElement _requiredParameter(String name, DartType type) {
+  ParameterElementImpl _requiredParameter(String name, TypeImpl type) {
     var parameter = ParameterElementImpl(
       name: name,
       nameOffset: 0,
@@ -1109,30 +1196,45 @@ class _MockSdkElementsBuilder {
   ) {
     classElement.accessors = accessors;
     classElement.fields = accessors
-        .map((accessor) => accessor.variable)
+        .map((accessor) => accessor.variable2)
         .cast<FieldElementImpl>()
         .toList();
   }
 
   TopLevelVariableElementImpl _topLevelVariableConst(
     String name,
-    DartType type,
+    TypeImpl type,
   ) {
-    final variable = ConstTopLevelVariableElementImpl(name, -1)
+    var fragment = ConstTopLevelVariableElementImpl(name, -1)
       ..isConst = true
       ..type = type;
-    PropertyAccessorElementImpl_ImplicitGetter(variable);
-    return variable;
+    TopLevelVariableElementImpl2(Reference.root(), fragment);
+    PropertyAccessorElementImpl_ImplicitGetter(fragment);
+    return fragment;
   }
 
   TypeParameterElementImpl _typeParameter(String name) {
     return TypeParameterElementImpl(name, 0);
   }
 
-  TypeParameterType _typeParameterType(TypeParameterElement element) {
+  TypeParameterTypeImpl _typeParameterType(TypeParameterElement element) {
     return TypeParameterTypeImpl(
       element: element,
       nullabilitySuffix: NullabilitySuffix.none,
     );
   }
+
+  static void _fillLibraryFromFragment(
+    LibraryElementImpl library,
+    CompilationUnitElementImpl fragment,
+  ) {
+    library.classes = fragment.classes.map((f) => f.element).toList();
+
+    library.topLevelFunctions = fragment.functions.map((f) {
+      return f.element as TopLevelFunctionElementImpl;
+    }).toList();
+
+    library.topLevelVariables =
+        fragment.topLevelVariables.map((f) => f.element).toList();
+  }
 }
