@@ -27,11 +27,12 @@ class A {}
 f(A a) {}
 ''');
 
-    final node = findNode.namedType('A a');
+    var node = findNode.namedType('A a');
     assertResolvedNodeText(node, r'''
 NamedType
   name: A
-  element: self::@class::A
+  element: <testLibraryFragment>::@class::A
+  element2: <testLibrary>::@class::A
   type: A
 ''');
   }
@@ -43,11 +44,12 @@ class A<T extends num> {}
 f(A a) {}
 ''');
 
-    final node = findNode.namedType('A a');
+    var node = findNode.namedType('A a');
     assertResolvedNodeText(node, r'''
 NamedType
   name: A
-  element: self::@class::A
+  element: <testLibraryFragment>::@class::A
+  element2: <testLibrary>::@class::A
   type: A<num>
 ''');
   }
@@ -59,11 +61,12 @@ class A<T> {}
 f(A a) {}
 ''');
 
-    final node = findNode.namedType('A a');
+    var node = findNode.namedType('A a');
     assertResolvedNodeText(node, r'''
 NamedType
   name: A
-  element: self::@class::A
+  element: <testLibraryFragment>::@class::A
+  element2: <testLibrary>::@class::A
   type: A<dynamic>
 ''');
   }
@@ -75,7 +78,7 @@ class A<T> {}
 f(A<int> a) {}
 ''');
 
-    final node = findNode.namedType('A<int> a');
+    var node = findNode.namedType('A<int> a');
     assertResolvedNodeText(node, r'''
 NamedType
   name: A
@@ -84,10 +87,12 @@ NamedType
     arguments
       NamedType
         name: int
-        element: dart:core::@class::int
+        element: dart:core::<fragment>::@class::int
+        element2: dart:core::@class::int
         type: int
     rightBracket: >
-  element: self::@class::A
+  element: <testLibraryFragment>::@class::A
+  element2: <testLibrary>::@class::A
   type: A<int>
 ''');
   }
@@ -99,11 +104,12 @@ import 'dart:core';
 dynamic a;
 ''');
 
-    final node = findNode.namedType('dynamic a;');
+    var node = findNode.namedType('dynamic a;');
     assertResolvedNodeText(node, r'''
 NamedType
   name: dynamic
   element: dynamic@-1
+  element2: dynamic
   type: dynamic
 ''');
   }
@@ -115,15 +121,17 @@ import 'dart:core' as myCore;
 myCore.dynamic a;
 ''');
 
-    final node = findNode.namedType('myCore.dynamic a;');
+    var node = findNode.namedType('myCore.dynamic a;');
     assertResolvedNodeText(node, r'''
 NamedType
   importPrefix: ImportPrefixReference
     name: myCore
     period: .
-    element: self::@prefix::myCore
+    element: <testLibraryFragment>::@prefix::myCore
+    element2: <testLibraryFragment>::@prefix2::myCore
   name: dynamic
   element: dynamic@-1
+  element2: dynamic
   type: dynamic
 ''');
   }
@@ -137,11 +145,12 @@ dynamic a;
       error(CompileTimeErrorCode.UNDEFINED_CLASS, 31, 7),
     ]);
 
-    final node = findNode.namedType('dynamic a;');
+    var node = findNode.namedType('dynamic a;');
     assertResolvedNodeText(node, r'''
 NamedType
   name: dynamic
   element: <null>
+  element2: <null>
   type: InvalidType
 ''');
   }
@@ -151,11 +160,12 @@ NamedType
 dynamic a;
 ''');
 
-    final node = findNode.namedType('dynamic a;');
+    var node = findNode.namedType('dynamic a;');
     assertResolvedNodeText(node, r'''
 NamedType
   name: dynamic
   element: dynamic@-1
+  element2: dynamic
   type: dynamic
 ''');
   }
@@ -167,7 +177,7 @@ class A<T> {}
 class B extends A<int> {}
 ''');
 
-    final node = findNode.namedType('A<int>');
+    var node = findNode.namedType('A<int>');
     assertResolvedNodeText(node, r'''
 NamedType
   name: A
@@ -176,10 +186,12 @@ NamedType
     arguments
       NamedType
         name: int
-        element: dart:core::@class::int
+        element: dart:core::<fragment>::@class::int
+        element2: dart:core::@class::int
         type: int
     rightBracket: >
-  element: self::@class::A
+  element: <testLibraryFragment>::@class::A
+  element2: <testLibrary>::@class::A
   type: A<int>
 ''');
   }
@@ -193,7 +205,7 @@ class B extends A<int> {}
       error(CompileTimeErrorCode.WRONG_NUMBER_OF_TYPE_ARGUMENTS, 34, 6),
     ]);
 
-    final node = findNode.namedType('A<int>');
+    var node = findNode.namedType('A<int>');
     assertResolvedNodeText(node, r'''
 NamedType
   name: A
@@ -202,10 +214,12 @@ NamedType
     arguments
       NamedType
         name: int
-        element: dart:core::@class::int
+        element: dart:core::<fragment>::@class::int
+        element2: dart:core::@class::int
         type: int
     rightBracket: >
-  element: self::@class::A
+  element: <testLibraryFragment>::@class::A
+  element2: <testLibrary>::@class::A
   type: A<InvalidType, InvalidType>
 ''');
   }
@@ -219,7 +233,7 @@ class B extends A<int, String> {}
       error(CompileTimeErrorCode.WRONG_NUMBER_OF_TYPE_ARGUMENTS, 31, 14),
     ]);
 
-    final node = findNode.namedType('A<int, String>');
+    var node = findNode.namedType('A<int, String>');
     assertResolvedNodeText(node, r'''
 NamedType
   name: A
@@ -228,14 +242,17 @@ NamedType
     arguments
       NamedType
         name: int
-        element: dart:core::@class::int
+        element: dart:core::<fragment>::@class::int
+        element2: dart:core::@class::int
         type: int
       NamedType
         name: String
-        element: dart:core::@class::String
+        element: dart:core::<fragment>::@class::String
+        element2: dart:core::@class::String
         type: String
     rightBracket: >
-  element: self::@class::A
+  element: <testLibraryFragment>::@class::A
+  element2: <testLibrary>::@class::A
   type: A<InvalidType>
 ''');
   }
@@ -248,7 +265,7 @@ class A<T> extends T<int> {}
       error(CompileTimeErrorCode.EXTENDS_NON_CLASS, 19, 1),
     ]);
 
-    final node = findNode.namedType('T<int>');
+    var node = findNode.namedType('T<int>');
     assertResolvedNodeText(node, r'''
 NamedType
   name: T
@@ -257,10 +274,12 @@ NamedType
     arguments
       NamedType
         name: int
-        element: dart:core::@class::int
+        element: dart:core::<fragment>::@class::int
+        element2: dart:core::@class::int
         type: int
     rightBracket: >
   element: T@8
+  element2: <not-implemented>
   type: T
 ''');
   }
@@ -271,11 +290,12 @@ extension type A<T extends num>(List<T> it) {}
 void f(A a) {}
 ''');
 
-    final node = findNode.namedType('A a');
+    var node = findNode.namedType('A a');
     assertResolvedNodeText(node, r'''
 NamedType
   name: A
-  element: self::@extensionType::A
+  element: <testLibraryFragment>::@extensionType::A
+  element2: <testLibrary>::@extensionType::A
   type: A<num>
 ''');
   }
@@ -286,11 +306,12 @@ extension type A<T>(List<T> it) {}
 void f(A a) {}
 ''');
 
-    final node = findNode.namedType('A a');
+    var node = findNode.namedType('A a');
     assertResolvedNodeText(node, r'''
 NamedType
   name: A
-  element: self::@extensionType::A
+  element: <testLibraryFragment>::@extensionType::A
+  element2: <testLibrary>::@extensionType::A
   type: A<dynamic>
 ''');
   }
@@ -301,7 +322,7 @@ extension type A<T>(List<T> it) {}
 void f(A<int> a) {}
 ''');
 
-    final node = findNode.namedType('A<int>');
+    var node = findNode.namedType('A<int>');
     assertResolvedNodeText(node, r'''
 NamedType
   name: A
@@ -310,10 +331,12 @@ NamedType
     arguments
       NamedType
         name: int
-        element: dart:core::@class::int
+        element: dart:core::<fragment>::@class::int
+        element2: dart:core::@class::int
         type: int
     rightBracket: >
-  element: self::@extensionType::A
+  element: <testLibraryFragment>::@extensionType::A
+  element2: <testLibrary>::@extensionType::A
   type: A<int>
 ''');
   }
@@ -325,13 +348,14 @@ typedef F = int Function();
 f(F a) {}
 ''');
 
-    final node = findNode.namedType('F a');
+    var node = findNode.namedType('F a');
     assertResolvedNodeText(node, r'''
 NamedType
   name: F
-  element: self::@typeAlias::F
+  element: <testLibraryFragment>::@typeAlias::F
+  element2: <testLibrary>::@typeAlias::F
   type: int Function()
-    alias: self::@typeAlias::F
+    alias: <testLibraryFragment>::@typeAlias::F
 ''');
   }
 
@@ -342,13 +366,14 @@ typedef F<T extends num> = T Function();
 f(F a) {}
 ''');
 
-    final node = findNode.namedType('F a');
+    var node = findNode.namedType('F a');
     assertResolvedNodeText(node, r'''
 NamedType
   name: F
-  element: self::@typeAlias::F
+  element: <testLibraryFragment>::@typeAlias::F
+  element2: <testLibrary>::@typeAlias::F
   type: num Function()
-    alias: self::@typeAlias::F
+    alias: <testLibraryFragment>::@typeAlias::F
       typeArguments
         num
 ''');
@@ -361,13 +386,14 @@ typedef F<T> = T Function();
 f(F a) {}
 ''');
 
-    final node = findNode.namedType('F a');
+    var node = findNode.namedType('F a');
     assertResolvedNodeText(node, r'''
 NamedType
   name: F
-  element: self::@typeAlias::F
+  element: <testLibraryFragment>::@typeAlias::F
+  element2: <testLibrary>::@typeAlias::F
   type: dynamic Function()
-    alias: self::@typeAlias::F
+    alias: <testLibraryFragment>::@typeAlias::F
       typeArguments
         dynamic
 ''');
@@ -380,7 +406,7 @@ typedef F<T> = T Function();
 f(F<int> a) {}
 ''');
 
-    final node = findNode.namedType('F<int> a');
+    var node = findNode.namedType('F<int> a');
     assertResolvedNodeText(node, r'''
 NamedType
   name: F
@@ -389,12 +415,14 @@ NamedType
     arguments
       NamedType
         name: int
-        element: dart:core::@class::int
+        element: dart:core::<fragment>::@class::int
+        element2: dart:core::@class::int
         type: int
     rightBracket: >
-  element: self::@typeAlias::F
+  element: <testLibraryFragment>::@typeAlias::F
+  element2: <testLibrary>::@typeAlias::F
   type: int Function()
-    alias: self::@typeAlias::F
+    alias: <testLibraryFragment>::@typeAlias::F
       typeArguments
         int
 ''');
@@ -407,23 +435,26 @@ import 'dart:async' as async;
 void f(async.Future<int> a) {}
 ''');
 
-    final node = findNode.namedType('async.Future');
+    var node = findNode.namedType('async.Future');
     assertResolvedNodeText(node, r'''
 NamedType
   importPrefix: ImportPrefixReference
     name: async
     period: .
-    element: self::@prefix::async
+    element: <testLibraryFragment>::@prefix::async
+    element2: <testLibraryFragment>::@prefix2::async
   name: Future
   typeArguments: TypeArgumentList
     leftBracket: <
     arguments
       NamedType
         name: int
-        element: dart:core::@class::int
+        element: dart:core::<fragment>::@class::int
+        element2: dart:core::@class::int
         type: int
     rightBracket: >
-  element: dart:async::@class::Future
+  element: dart:async::<fragment>::@class::Future
+  element2: dart:async::@class::Future
   type: Future<int>
 ''');
   }
@@ -437,23 +468,26 @@ void f(math.Unresolved<int> a) {}
       error(CompileTimeErrorCode.UNDEFINED_CLASS, 36, 15),
     ]);
 
-    final node = findNode.namedType('math.Unresolved');
+    var node = findNode.namedType('math.Unresolved');
     assertResolvedNodeText(node, r'''
 NamedType
   importPrefix: ImportPrefixReference
     name: math
     period: .
-    element: self::@prefix::math
+    element: <testLibraryFragment>::@prefix::math
+    element2: <testLibraryFragment>::@prefix2::math
   name: Unresolved
   typeArguments: TypeArgumentList
     leftBracket: <
     arguments
       NamedType
         name: int
-        element: dart:core::@class::int
+        element: dart:core::<fragment>::@class::int
+        element2: dart:core::@class::int
         type: int
     rightBracket: >
   element: <null>
+  element2: <null>
   type: InvalidType
 ''');
   }
@@ -469,15 +503,17 @@ main() {
       error(CompileTimeErrorCode.NEW_WITH_NON_TYPE, 49, 1),
     ]);
 
-    final node = findNode.namedType('A();');
+    var node = findNode.namedType('A();');
     assertResolvedNodeText(node, r'''
 NamedType
   importPrefix: ImportPrefixReference
     name: math
     period: .
-    element: self::@prefix::math
+    element: <testLibraryFragment>::@prefix::math
+    element2: <testLibraryFragment>::@prefix2::math
   name: A
   element: <null>
+  element2: <null>
   type: InvalidType
 ''');
   }
@@ -491,11 +527,12 @@ main() {
 }
 ''');
 
-    final node = findNode.namedType('A();');
+    var node = findNode.namedType('A();');
     assertResolvedNodeText(node, r'''
 NamedType
   name: A
-  element: self::@class::A
+  element: <testLibraryFragment>::@class::A
+  element2: <testLibrary>::@class::A
   type: A
 ''');
   }
@@ -509,11 +546,12 @@ main() {
       error(CompileTimeErrorCode.NEW_WITH_NON_TYPE, 15, 1),
     ]);
 
-    final node = findNode.namedType('A();');
+    var node = findNode.namedType('A();');
     assertResolvedNodeText(node, r'''
 NamedType
   name: A
   element: <null>
+  element2: <null>
   type: InvalidType
 ''');
   }
@@ -530,23 +568,26 @@ void f() {
       error(WarningCode.UNUSED_LOCAL_VARIABLE, 71, 1),
     ]);
 
-    final node = findNode.namedType('async.Future');
+    var node = findNode.namedType('async.Future');
     assertResolvedNodeText(node, r'''
 NamedType
   importPrefix: ImportPrefixReference
     name: async
     period: .
-    element: self::@prefix::async
+    element: <testLibraryFragment>::@prefix::async
+    element2: <testLibraryFragment>::@prefix2::async
   name: Future
   typeArguments: TypeArgumentList
     leftBracket: <
     arguments
       NamedType
         name: int
-        element: dart:core::@class::int
+        element: dart:core::<fragment>::@class::int
+        element2: dart:core::@class::int
         type: int
     rightBracket: >
-  element: dart:async::@class::Future
+  element: dart:async::<fragment>::@class::Future
+  element2: dart:async::@class::Future
   type: Future<int>
 ''');
   }
@@ -560,11 +601,12 @@ void f(prefix a) {}
       error(CompileTimeErrorCode.NOT_A_TYPE, 38, 6),
     ]);
 
-    final node = findNode.namedType('prefix a');
+    var node = findNode.namedType('prefix a');
     assertResolvedNodeText(node, r'''
 NamedType
   name: prefix
-  element: self::@prefix::prefix
+  element: <testLibraryFragment>::@prefix::prefix
+  element2: <testLibraryFragment>::@prefix2::prefix
   type: InvalidType
 ''');
   }
@@ -578,7 +620,7 @@ void f(prefix<int> a) {}
       error(CompileTimeErrorCode.NOT_A_TYPE, 38, 6),
     ]);
 
-    final node = findNode.namedType('prefix<int>');
+    var node = findNode.namedType('prefix<int>');
     assertResolvedNodeText(node, r'''
 NamedType
   name: prefix
@@ -587,10 +629,12 @@ NamedType
     arguments
       NamedType
         name: int
-        element: dart:core::@class::int
+        element: dart:core::<fragment>::@class::int
+        element2: dart:core::@class::int
         type: int
     rightBracket: >
-  element: self::@prefix::prefix
+  element: <testLibraryFragment>::@prefix::prefix
+  element2: <testLibraryFragment>::@prefix2::prefix
   type: InvalidType
 ''');
   }
@@ -604,15 +648,17 @@ void f() {
       error(CompileTimeErrorCode.NEW_WITH_NON_TYPE, 17, 10),
     ]);
 
-    final node = findNode.namedType('int.double');
+    var node = findNode.namedType('int.double');
     assertResolvedNodeText(node, r'''
 NamedType
   importPrefix: ImportPrefixReference
     name: int
     period: .
-    element: dart:core::@class::int
+    element: dart:core::<fragment>::@class::int
+    element2: dart:core::@class::int
   name: double
   element: <null>
+  element2: <null>
   type: InvalidType
 ''');
   }
@@ -626,15 +672,17 @@ void f() {
       error(CompileTimeErrorCode.NOT_A_TYPE, 18, 10),
     ]);
 
-    final node = findNode.namedType('int.double');
+    var node = findNode.namedType('int.double');
     assertResolvedNodeText(node, r'''
 NamedType
   importPrefix: ImportPrefixReference
     name: int
     period: .
-    element: dart:core::@class::int
+    element: dart:core::<fragment>::@class::int
+    element2: dart:core::@class::int
   name: double
   element: <null>
+  element2: <null>
   type: InvalidType
 ''');
   }
@@ -648,11 +696,12 @@ void T() {}
       error(CompileTimeErrorCode.NOT_A_TYPE, 7, 1),
     ]);
 
-    final node = findNode.namedType('T a');
+    var node = findNode.namedType('T a');
     assertResolvedNodeText(node, r'''
 NamedType
   name: T
-  element: self::@function::T
+  element: <testLibraryFragment>::@function::T
+  element2: <testLibrary>::@function::T
   type: InvalidType
 ''');
   }
@@ -666,7 +715,7 @@ void T() {}
       error(CompileTimeErrorCode.NOT_A_TYPE, 7, 1),
     ]);
 
-    final node = findNode.namedType('T<int>');
+    var node = findNode.namedType('T<int>');
     assertResolvedNodeText(node, r'''
 NamedType
   name: T
@@ -675,10 +724,12 @@ NamedType
     arguments
       NamedType
         name: int
-        element: dart:core::@class::int
+        element: dart:core::<fragment>::@class::int
+        element2: dart:core::@class::int
         type: int
     rightBracket: >
-  element: self::@function::T
+  element: <testLibraryFragment>::@function::T
+  element2: <testLibrary>::@function::T
   type: InvalidType
 ''');
   }
@@ -690,23 +741,26 @@ void f<T>(T.name<int> a) {}
       error(CompileTimeErrorCode.PREFIX_SHADOWED_BY_LOCAL_DECLARATION, 10, 1),
     ]);
 
-    final node = findNode.namedType('T.name<int>');
+    var node = findNode.namedType('T.name<int>');
     assertResolvedNodeText(node, r'''
 NamedType
   importPrefix: ImportPrefixReference
     name: T
     period: .
     element: T@7
+    element2: <not-implemented>
   name: name
   typeArguments: TypeArgumentList
     leftBracket: <
     arguments
       NamedType
         name: int
-        element: dart:core::@class::int
+        element: dart:core::<fragment>::@class::int
+        element2: dart:core::@class::int
         type: int
     rightBracket: >
   element: <null>
+  element2: <null>
   type: InvalidType
 ''');
   }
@@ -729,11 +783,14 @@ void f(A a) {}
       error(CompileTimeErrorCode.AMBIGUOUS_IMPORT, 42, 1),
     ]);
 
-    final node = findNode.namedType('A a');
+    var node = findNode.namedType('A a');
     assertResolvedNodeText(node, r'''
 NamedType
   name: A
   element: <null>
+  element2: multiplyDefinedElement
+    package:test/a.dart::@class::A
+    package:test/b.dart::@class::A
   type: InvalidType
 ''');
   }
@@ -743,11 +800,12 @@ NamedType
 f(Never a) {}
 ''');
 
-    final node = findNode.namedType('Never a');
+    var node = findNode.namedType('Never a');
     assertResolvedNodeText(node, r'''
 NamedType
   name: Never
   element: Never@-1
+  element2: Never
   type: Never
 ''');
   }
@@ -763,7 +821,7 @@ void f() {
 }
 ''');
 
-    final node = findNode.namedType('X<int>()');
+    var node = findNode.namedType('X<int>()');
     assertResolvedNodeText(node, r'''
 NamedType
   name: X
@@ -772,10 +830,12 @@ NamedType
     arguments
       NamedType
         name: int
-        element: dart:core::@class::int
+        element: dart:core::<fragment>::@class::int
+        element2: dart:core::@class::int
         type: int
     rightBracket: >
-  element: self::@typeAlias::X
+  element: <testLibraryFragment>::@typeAlias::X
+  element2: <testLibrary>::@typeAlias::X
   type: A<int>
 ''');
   }
@@ -791,11 +851,12 @@ void f() {
 }
 ''');
 
-    final node = findNode.namedType('X()');
+    var node = findNode.namedType('X()');
     assertResolvedNodeText(node, r'''
 NamedType
   name: X
-  element: self::@typeAlias::X
+  element: <testLibraryFragment>::@typeAlias::X
+  element2: <testLibrary>::@typeAlias::X
   type: A<int>
 ''');
   }
@@ -811,7 +872,7 @@ void f() {
 }
 ''');
 
-    final node = findNode.namedType('X<int>()');
+    var node = findNode.namedType('X<int>()');
     assertResolvedNodeText(node, r'''
 NamedType
   name: X
@@ -820,10 +881,12 @@ NamedType
     arguments
       NamedType
         name: int
-        element: dart:core::@class::int
+        element: dart:core::<fragment>::@class::int
+        element2: dart:core::@class::int
         type: int
     rightBracket: >
-  element: self::@typeAlias::X
+  element: <testLibraryFragment>::@typeAlias::X
+  element2: <testLibrary>::@typeAlias::X
   type: A<int>
 ''');
   }
@@ -834,7 +897,7 @@ typedef X<T> = Map<int, T>;
 void f(X<String> a, X<String?> b) {}
 ''');
 
-    final node1 = findNode.namedType('X<String>');
+    var node1 = findNode.namedType('X<String>');
     assertResolvedNodeText(node1, r'''
 NamedType
   name: X
@@ -843,17 +906,19 @@ NamedType
     arguments
       NamedType
         name: String
-        element: dart:core::@class::String
+        element: dart:core::<fragment>::@class::String
+        element2: dart:core::@class::String
         type: String
     rightBracket: >
-  element: self::@typeAlias::X
+  element: <testLibraryFragment>::@typeAlias::X
+  element2: <testLibrary>::@typeAlias::X
   type: Map<int, String>
-    alias: self::@typeAlias::X
+    alias: <testLibraryFragment>::@typeAlias::X
       typeArguments
         String
 ''');
 
-    final node2 = findNode.namedType('X<String?>');
+    var node2 = findNode.namedType('X<String?>');
     assertResolvedNodeText(node2, r'''
 NamedType
   name: X
@@ -863,12 +928,14 @@ NamedType
       NamedType
         name: String
         question: ?
-        element: dart:core::@class::String
+        element: dart:core::<fragment>::@class::String
+        element2: dart:core::@class::String
         type: String?
     rightBracket: >
-  element: self::@typeAlias::X
+  element: <testLibraryFragment>::@typeAlias::X
+  element2: <testLibrary>::@typeAlias::X
   type: Map<int, String?>
-    alias: self::@typeAlias::X
+    alias: <testLibraryFragment>::@typeAlias::X
       typeArguments
         String?
 ''');
@@ -880,7 +947,7 @@ typedef X<T> = List<T?>;
 void f(X<int> a, X<int?> b) {}
 ''');
 
-    final node1 = findNode.namedType('X<int>');
+    var node1 = findNode.namedType('X<int>');
     assertResolvedNodeText(node1, r'''
 NamedType
   name: X
@@ -889,17 +956,19 @@ NamedType
     arguments
       NamedType
         name: int
-        element: dart:core::@class::int
+        element: dart:core::<fragment>::@class::int
+        element2: dart:core::@class::int
         type: int
     rightBracket: >
-  element: self::@typeAlias::X
+  element: <testLibraryFragment>::@typeAlias::X
+  element2: <testLibrary>::@typeAlias::X
   type: List<int?>
-    alias: self::@typeAlias::X
+    alias: <testLibraryFragment>::@typeAlias::X
       typeArguments
         int
 ''');
 
-    final node2 = findNode.namedType('X<int?>');
+    var node2 = findNode.namedType('X<int?>');
     assertResolvedNodeText(node2, r'''
 NamedType
   name: X
@@ -909,12 +978,14 @@ NamedType
       NamedType
         name: int
         question: ?
-        element: dart:core::@class::int
+        element: dart:core::<fragment>::@class::int
+        element2: dart:core::@class::int
         type: int?
     rightBracket: >
-  element: self::@typeAlias::X
+  element: <testLibraryFragment>::@typeAlias::X
+  element2: <testLibrary>::@typeAlias::X
   type: List<int?>
-    alias: self::@typeAlias::X
+    alias: <testLibraryFragment>::@typeAlias::X
       typeArguments
         int?
 ''');
@@ -926,20 +997,22 @@ typedef X = Never;
 void f(X a, X? b) {}
 ''');
 
-    final node1 = findNode.namedType('X a');
+    var node1 = findNode.namedType('X a');
     assertResolvedNodeText(node1, r'''
 NamedType
   name: X
-  element: self::@typeAlias::X
+  element: <testLibraryFragment>::@typeAlias::X
+  element2: <testLibrary>::@typeAlias::X
   type: Never
 ''');
 
-    final node2 = findNode.namedType('X? b');
+    var node2 = findNode.namedType('X? b');
     assertResolvedNodeText(node2, r'''
 NamedType
   name: X
   question: ?
-  element: self::@typeAlias::X
+  element: <testLibraryFragment>::@typeAlias::X
+  element2: <testLibrary>::@typeAlias::X
   type: Never?
 ''');
   }
@@ -950,20 +1023,22 @@ typedef X = Never?;
 void f(X a, X? b) {}
 ''');
 
-    final node1 = findNode.namedType('X a');
+    var node1 = findNode.namedType('X a');
     assertResolvedNodeText(node1, r'''
 NamedType
   name: X
-  element: self::@typeAlias::X
+  element: <testLibraryFragment>::@typeAlias::X
+  element2: <testLibrary>::@typeAlias::X
   type: Never?
 ''');
 
-    final node2 = findNode.namedType('X? b');
+    var node2 = findNode.namedType('X? b');
     assertResolvedNodeText(node2, r'''
 NamedType
   name: X
   question: ?
-  element: self::@typeAlias::X
+  element: <testLibraryFragment>::@typeAlias::X
+  element2: <testLibrary>::@typeAlias::X
   type: Never?
 ''');
   }
@@ -974,7 +1049,7 @@ typedef X<T> = T?;
 void f(X<int> a) {}
 ''');
 
-    final node = findNode.namedType('X<int>');
+    var node = findNode.namedType('X<int>');
     assertResolvedNodeText(node, r'''
 NamedType
   name: X
@@ -983,12 +1058,14 @@ NamedType
     arguments
       NamedType
         name: int
-        element: dart:core::@class::int
+        element: dart:core::<fragment>::@class::int
+        element2: dart:core::@class::int
         type: int
     rightBracket: >
-  element: self::@typeAlias::X
+  element: <testLibraryFragment>::@typeAlias::X
+  element2: <testLibrary>::@typeAlias::X
   type: int?
-    alias: self::@typeAlias::X
+    alias: <testLibraryFragment>::@typeAlias::X
       typeArguments
         int
 ''');
@@ -1000,7 +1077,7 @@ typedef X<T> = Map<int, T>;
 X<String> f() => {};
 ''');
 
-    final node = findNode.namedType('X<String>');
+    var node = findNode.namedType('X<String>');
     assertResolvedNodeText(node, r'''
 NamedType
   name: X
@@ -1009,12 +1086,14 @@ NamedType
     arguments
       NamedType
         name: String
-        element: dart:core::@class::String
+        element: dart:core::<fragment>::@class::String
+        element2: dart:core::@class::String
         type: String
     rightBracket: >
-  element: self::@typeAlias::X
+  element: <testLibraryFragment>::@typeAlias::X
+  element2: <testLibrary>::@typeAlias::X
   type: Map<int, String>
-    alias: self::@typeAlias::X
+    alias: <testLibraryFragment>::@typeAlias::X
       typeArguments
         String
 ''');
@@ -1026,11 +1105,12 @@ typedef Nothing = void;
 Nothing f() {}
 ''');
 
-    final node = findNode.namedType('Nothing f()');
+    var node = findNode.namedType('Nothing f()');
     assertResolvedNodeText(node, r'''
 NamedType
   name: Nothing
-  element: self::@typeAlias::Nothing
+  element: <testLibraryFragment>::@typeAlias::Nothing
+  element2: <testLibrary>::@typeAlias::Nothing
   type: void
 ''');
   }
@@ -1042,7 +1122,7 @@ void f(Unresolved<int> a) {}
       error(CompileTimeErrorCode.UNDEFINED_CLASS, 7, 10),
     ]);
 
-    final node = findNode.namedType('Unresolved');
+    var node = findNode.namedType('Unresolved');
     assertResolvedNodeText(node, r'''
 NamedType
   name: Unresolved
@@ -1051,10 +1131,12 @@ NamedType
     arguments
       NamedType
         name: int
-        element: dart:core::@class::int
+        element: dart:core::<fragment>::@class::int
+        element2: dart:core::@class::int
         type: int
     rightBracket: >
   element: <null>
+  element2: <null>
   type: InvalidType
 ''');
   }
@@ -1066,23 +1148,26 @@ void f(unresolved.List<int> a) {}
       error(CompileTimeErrorCode.UNDEFINED_CLASS, 7, 15),
     ]);
 
-    final node = findNode.namedType('unresolved.List');
+    var node = findNode.namedType('unresolved.List');
     assertResolvedNodeText(node, r'''
 NamedType
   importPrefix: ImportPrefixReference
     name: unresolved
     period: .
     element: <null>
+    element2: <null>
   name: List
   typeArguments: TypeArgumentList
     leftBracket: <
     arguments
       NamedType
         name: int
-        element: dart:core::@class::int
+        element: dart:core::<fragment>::@class::int
+        element2: dart:core::@class::int
         type: int
     rightBracket: >
   element: <null>
+  element2: <null>
   type: InvalidType
 ''');
   }
